@@ -27,6 +27,13 @@ def setup_default_routes(app):
     def _health_check_service():
         return dict(name="{} Service".format(app.config.get('SERVICE_NAME')), works=True)
 
+    @route(
+        path='/health_check',
+        require_auth=False
+    )
+    def _health_check_with_path_service():
+        return dict(name="{} Service".format(app.config.get('SERVICE_NAME')), works=True)
+
     @route("/fetch_relational_data", methods=["POST"], require_auth=False)
     def _fetch_relational_data_service(validated_data):
         """
